@@ -63,6 +63,7 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
 #endif
 {
     ui->setupUi(this);
+    soundEffect = new QSoundEffect();
 
     sliderScreencastCountDown = new QvkSpezialSlider( Qt::Horizontal );
     ui->gridLayout_9->addWidget( sliderScreencastCountDown, 2, 1 );
@@ -170,6 +171,11 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     QvkLogController *vklogController = new QvkLogController( ui );
     Q_UNUSED(vklogController);
 
+#ifdef Q_OS_LINUX
+    ui->pushButtonSendReport->setHidden( true );
+    ui->help_log_sendreport->setHidden( true );
+#endif
+
     setWindowTitle( global::name + " " + global::version );
     QIcon icon( QString::fromUtf8( ":/pictures/logo/logo.png" ) );
     setWindowIcon( icon );
@@ -363,8 +369,6 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     connect( ui->radioButtonScreencastArea,   SIGNAL( toggled( bool ) ), ui->comboBoxAreaSize, SLOT( setEnabled( bool ) ) );
     connect( ui->radioButtonScreencastArea,   SIGNAL( toggled( bool ) ), ui->comboBoxScreencastScreenArea, SLOT( setEnabled( bool ) ) );
 
-    connect( ui->comboBoxScreencastScreenArea,SIGNAL( currentIndexChanged(int) ),  vkRegionChoise, SLOT( slot_init() ) );
-
     connect( ui->toolButtonScreencastAreaReset, SIGNAL( clicked( bool ) ), vkRegionChoise, SLOT( slot_areaReset() ) );
     connect( ui->toolButtonScreencastAreaReset, SIGNAL( clicked( bool ) ), this,           SLOT( slot_areaReset() ) );
     connect( ui->pushButtonStart,     SIGNAL( clicked( bool ) ), this, SLOT( slot_disableAreaWidgets() ) );
@@ -375,21 +379,19 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
 
 
     // Tab 2 Audio and Videocodec
-#ifdef Q_OS_LINUX
-    QvkAudioPulse *vkAudioPulse = new QvkAudioPulse( ui );
-    connect( vkAudioPulse, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), this,                   SLOT( slot_audioIconOnOff( bool ) ) );
-    connect( vkAudioPulse, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), ui->labelAudioCodec,    SLOT( setEnabled( bool ) ) );
-    connect( vkAudioPulse, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), ui->comboBoxAudioCodec, SLOT( setEnabled( bool ) ) );
-    vkAudioPulse->init();
+#ifdef Q_OS_WIN
+    // Alle Funktionen werden innerhalb dieser Klasse aufgerufen
+    vkAudioController = new QvkAudioController( ui );
 #endif
 
-#ifdef Q_OS_WIN
-    QvkAudioWindows *vkAudioWindows = new QvkAudioWindows( ui );
-    connect( vkAudioWindows, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), this,                   SLOT( slot_audioIconOnOff( bool ) ) );
-    connect( vkAudioWindows, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), ui->labelAudioCodec,    SLOT( setEnabled( bool ) ) );
-    connect( vkAudioWindows, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), ui->comboBoxAudioCodec, SLOT( setEnabled( bool ) ) );
-    vkAudioWindows->init();
+#ifdef Q_OS_LINUX
+    vkAudioController = new QvkAudioController( ui );
+    connect( vkAudioController, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), this,                   SLOT( slot_audioIconOnOff( bool ) ) );
+    connect( vkAudioController, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), ui->labelAudioCodec,    SLOT( setEnabled( bool ) ) );
+    connect( vkAudioController, SIGNAL( signal_haveAudioDeviceSelected( bool ) ), ui->comboBoxAudioCodec, SLOT( setEnabled( bool ) ) );
+    vkAudioController->init();
 #endif
+
     connect( vkTheme, SIGNAL( signal_newTheme() ), this, SLOT( slot_audioRedCross() ) );
 
     connect( ui->toolButtonFramesReset, SIGNAL( clicked( bool ) ), this, SLOT( slot_framesReset() ) );
@@ -471,6 +473,7 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     // Area
     connect( screenManager, SIGNAL( signal_clear_widget() ),                          ui->comboBoxScreencastScreenArea, SLOT( clear() ) );
     connect( screenManager, SIGNAL( signal_screen_count_changed( QString, QString) ), this,                             SLOT( slot_screenCountChangedArea( QString, QString ) ) );
+    connect( ui->comboBoxScreencastScreenArea, SIGNAL( currentIndexChanged( int) ),  vkRegionChoise, SLOT( slot_init() ) );
     emit qApp->screenAdded(Q_NULLPTR);
 
     // *****************Begin Camera *********************************
@@ -496,6 +499,9 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     vkSettings.readCamera( vkCameraController );
     vkSettings.readSystrayAlternative( vkSystrayAlternative );
     vkSettings.readPlayerPathOpenFile( vkPlayer );
+#ifdef Q_OS_WIN
+//    vkAudioController->slot_audioDeviceSelected();
+#endif
 
     // After reading the settings, we read the arguments and run
     QStringList arguments = QApplication::instance()->arguments();
@@ -1114,6 +1120,7 @@ void QvkMainWindow::VK_gst_Elements_available()
     QStringList list;
 #ifdef Q_OS_WIN
     list << "gdiscreencapsrc";
+    list << "wasapisrc";
     list << "directsoundsrc";
 #endif
 #ifdef Q_OS_LINUX
@@ -1130,6 +1137,7 @@ void QvkMainWindow::VK_gst_Elements_available()
     list << "filesink";
     list << "videoscale";
     list << "h264parse";
+    list << "audiomixer";
     list << "adder";
 
     for ( int i = 0; i < list.count(); i++ )
@@ -1271,7 +1279,7 @@ void QvkMainWindow::VK_Supported_Formats_And_Codecs()
                                     << "audiocodec:flacenc:flac"
                                     << "audiocodec:opusenc:opus"
                                     << "audiocodec:lamemp3enc:mp3"
-                                    << "audiocodec:faac:aac"
+                                    << "audiocodec:voaacenc:aac"
                                    );
 
     QStringList WEBM_QStringList = ( QStringList()
@@ -1295,7 +1303,7 @@ void QvkMainWindow::VK_Supported_Formats_And_Codecs()
                                 #endif
                                      << "videocodec:vp8enc:VP8"
                                      << "audiocodec:lamemp3enc:mp3"
-                                     << "audiocodec:faac:aac"
+                                     << "audiocodec:voaacenc:aac"
                                    );
 
     QStringList MP4_QStringList = ( QStringList()
@@ -1310,9 +1318,10 @@ void QvkMainWindow::VK_Supported_Formats_And_Codecs()
                                 #endif
                                     << "audiocodec:lamemp3enc:mp3"
                                     << "audiocodec:opusenc:opus"
-                                    << "audiocodec:faac:aac"
+                                    << "audiocodec:voaacenc:aac"
                                   );
 
+    // https://de.wikipedia.org/wiki/QuickTime
     QStringList MOV_QStringList = ( QStringList()
                                     << "muxer:qtmux:mov"
                                     << "videomimetype:video/mp4"
@@ -1325,8 +1334,7 @@ void QvkMainWindow::VK_Supported_Formats_And_Codecs()
                                 #endif
                                     << "videocodec:vp8enc:VP8"
                                     << "audiocodec:lamemp3enc:mp3"
-                                    << "audiocodec:opusenc:opus"
-                                    << "audiocodec:faac:aac"
+                                    << "audiocodec:voaacenc:aac"
                                   );
 
     videoFormatsList.clear();
@@ -1667,14 +1675,6 @@ QString QvkMainWindow::VK_get_AudioSystem()
 #endif
 
 
-#ifdef Q_OS_WIN
-QString QvkMainWindow::VK_get_AudioSystem()
-{
-    return "directsoundsrc";
-}
-#endif
-
-
 QString QvkMainWindow::VK_getMuxer()
 {
     QString value = ui->comboBoxFormat->currentData().toString();
@@ -1690,7 +1690,6 @@ QString QvkMainWindow::VK_getMuxer()
 }
 
 
-
 QStringList QvkMainWindow::VK_getSelectedAudioDevice()
 {
     QStringList list;
@@ -1709,15 +1708,18 @@ QStringList QvkMainWindow::VK_getSelectedAudioDevice()
 QString QvkMainWindow::Pipeline_structured_output( QString pipeline )
 {
     QString string;
+    QString nl;
 #ifdef Q_OS_LINUX
-    string = pipeline.prepend( "gst-launch-1.0 -e \\\n    " );
+    nl = "\\";
+    string = pipeline.prepend( "gst-launch-1.0 -e " + nl + "\n    " );
 #endif
 #ifdef Q_OS_WIN
-    string = pipeline.prepend( "gst-launch-1.0.exe -e \\\n    " );
+    nl = "^";
+    string = pipeline.prepend( "gst-launch-1.0.exe -e " + nl + "\n    " );
 #endif
-    string = pipeline.replace( "mux.", "mux. \\\n   " );
-    string = pipeline.replace( "mix.", "mix. \\\n   " );
-    string = pipeline.replace( "!", "\\\n        !" );
+    string = pipeline.replace( "mux.", "mux. " + nl + "\n   " );
+    string = pipeline.replace( "mix.", "mix. " + nl + "\n   " );
+    string = pipeline.replace( "!", nl + "\n        !" );
     string.append( "\n" );
     return string;
 }
@@ -1747,23 +1749,51 @@ void QvkMainWindow::slot_Start()
     }
 
     // Pipeline for one selected audiodevice
-    // 2019-09-28 tested and ok on opensuse 15.0 und nativ Windows 10 from USB-Stick
     if ( ( VK_getSelectedAudioDevice().count() == 1 ) and ( ui->comboBoxAudioCodec->count() > 0 ) )
     {
         #ifdef Q_OS_LINUX
             VK_PipelineList << VK_get_AudioSystem().append( " device=" ).append( VK_getSelectedAudioDevice().at(0) );
+            VK_PipelineList << "audio/x-raw, channels=2";
+            VK_PipelineList << "audioconvert";
+            VK_PipelineList << "audiorate";
+            VK_PipelineList << ui->comboBoxAudioCodec->currentData().toString();
+            VK_PipelineList << "queue";
+            VK_PipelineList << "mux.";
         #endif
 
         #ifdef Q_OS_WIN
-            VK_PipelineList << VK_get_AudioSystem().append( " device-name=" ).append( "'" + VK_getSelectedAudioDevice().at(0) +"'" );
+            if ( vkAudioController->radioButtonWASAPI->isChecked() )
+            {
+                if ( VK_getSelectedAudioDevice().at(0).section( ":::", 1, 1 ) == "Playback" )
+                {
+                    soundEffect->setSource( QUrl::fromLocalFile( ":/sound/wasapi.wav" ) );
+                    soundEffect->setLoopCount( QSoundEffect::Infinite );
+                    soundEffect->setVolume( 0.0 );
+                    soundEffect->play();
+                    VK_PipelineList << QString( "wasapisrc loopback=true low-latency=true role=multimedia device=" ).append( VK_getSelectedAudioDevice().at(0).section( ":::", 0, 0 ) );
+                }
+                else
+                {
+                    VK_PipelineList << QString( "wasapisrc low-latency=true role=multimedia device=" ).append( VK_getSelectedAudioDevice().at(0).section( ":::", 0, 0 ) );
+                }
+                VK_PipelineList << "audioconvert";
+                VK_PipelineList << "audiorate";
+                VK_PipelineList << ui->comboBoxAudioCodec->currentData().toString();
+                VK_PipelineList << "queue";
+                VK_PipelineList << "mux.";
+            }
+
+            if ( vkAudioController->radioButtonDirectSound->isChecked() )
+            {
+                VK_PipelineList << QString( "directsoundsrc device-name=" ).append( "'" + VK_getSelectedAudioDevice().at(0) + "'" );
+                VK_PipelineList << "audio/x-raw, channels=2";
+                VK_PipelineList << "audioconvert";
+                VK_PipelineList << "audiorate";
+                VK_PipelineList << ui->comboBoxAudioCodec->currentData().toString();
+                VK_PipelineList << "queue";
+                VK_PipelineList << "mux.";
+            }
         #endif
-        // We need more queue with enough buffers, then we have no dropaouts.
-        VK_PipelineList << "audio/x-raw, channels=2";
-        VK_PipelineList << "audioconvert";
-        VK_PipelineList << "audiorate";
-        VK_PipelineList << ui->comboBoxAudioCodec->currentData().toString();
-        VK_PipelineList << "queue";
-        VK_PipelineList << "mux.";
     }
 
     // Pipeline for more as one audiodevice
@@ -1779,13 +1809,16 @@ void QvkMainWindow::slot_Start()
             #endif
 
             #ifdef Q_OS_WIN
-                VK_PipelineList << VK_get_AudioSystem().append( " device-name=" ).append( "'" + VK_getSelectedAudioDevice().at(x) +"'" );
-                VK_PipelineList << "audio/x-raw, channels=2";
-                VK_PipelineList << "queue";
-                VK_PipelineList << "mix.";
+                if ( vkAudioController->radioButtonDirectSound->isCheckable() )
+                {
+                    VK_PipelineList << QString( "directsoundsrc device-name=" ).append( "'" + VK_getSelectedAudioDevice().at(x) + "'" );
+                    VK_PipelineList << "audio/x-raw, channels=2";
+                    VK_PipelineList << "queue";
+                    VK_PipelineList << "mix.";
+                }
             #endif
         }
-        VK_PipelineList << "adder name=mix";
+        VK_PipelineList << "audiomixer name=mix";
         VK_PipelineList << "audioconvert";
         VK_PipelineList << "audiorate";
         VK_PipelineList << ui->comboBoxAudioCodec->currentData().toString();
@@ -1877,6 +1910,10 @@ void QvkMainWindow::slot_Stop()
         qDebug().noquote() << global::nameOutput << "Stop record";
     }
 
+    #ifdef Q_OS_WIN
+       soundEffect->stop();
+    #endif
+
     wantRecording = true;
 
 }
@@ -1887,7 +1924,7 @@ void QvkMainWindow::slot_Pause()
     if ( ui->pushButtonStart->isEnabled() == false )
     {
         qDebug().noquote() << global::nameOutput << "Pause was clicked";
-        GstStateChangeReturn ret = gst_element_set_state( pipeline, GST_STATE_PAUSED ); // so wie es aussieht hängt er nur mit Audio
+        GstStateChangeReturn ret = gst_element_set_state( pipeline, GST_STATE_PAUSED );
         if ( ret == GST_STATE_CHANGE_FAILURE )   { qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_FAILURE" << "Returncode =" << ret;   } // 0
         if ( ret == GST_STATE_CHANGE_SUCCESS )   { qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_SUCCESS" << "Returncode =" << ret;   } // 1
         if ( ret == GST_STATE_CHANGE_ASYNC )     { qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_ASYNC" << "Returncode =" << ret;   }   // 2
